# Reference

Technical reference material including APIs and release notes.

```{toctree}
:maxdepth: 1
reference/recommended_hardware.md
reference/config.md
reference/client_service_api.md
reference/server_socket_api.md
reference/architecture.md
reference/govwifi_setup.md

API <_api/usb_remote>
genindex
Release Notes <https://github.com/epics-containers/usb-remote/releases>
```
